from _typeshed import Incomplete, ReadableBuffer, WriteableBuffer
from collections.abc import Callable
from typing import Literal, TypeVar

import _win32typing
from win32.lib.pywintypes import error as error

_T = TypeVar("_T")

def EnumFontFamilies(hdc: int, Family: str, EnumFontFamProc, Param, /): ...
def set_logger(logger, /) -> None: ...
def LOGFONT() -> _win32typing.PyLOGFONT: ...
def CreateFontIndirect(lplf: _win32typing.PyLOGFONT, /): ...
def GetObject(handle: int, /): ...
def GetObjectType(h: int, /): ...
def PyGetMemory(addr: int, len: int, /): ...
def PyGetString(addr, _len=..., /) -> str: ...
def PySetString(addr, String, maxLen, /): ...
def PySetMemory(addr, String, /): ...
def PyGetArraySignedLong(array, index, /): ...
def PyGetBufferAddressAndLen(obj, /): ...
def FlashWindow(hwnd: int, bInvert, /): ...
def FlashWindowEx(hwnd: int, dwFlags, uCount, dwTimeout, /): ...
def GetWindowLong(hwnd: int, index, /): ...
def GetClassLong(hwnd: int, index, /): ...
def SetWindowLong(hwnd: int, index, value, /): ...
def CallWindowProc(wndproc, hwnd: int, msg, wparam, lparam, /): ...
def CascadeWindows(
    hwndObject: _win32typing.PyHANDLE | int | None,
    how: int,
    rectObject: _win32typing.PyRECT | tuple[int, int, int, int] | int | None = None,
    childrenObject: tuple[_win32typing.PyHANDLE | int, ...] | None = None,
    /,
) -> int: ...
def SendMessage(
    hwnd: int | None, message: int, wparam: int | None = ..., lparam: ReadableBuffer | float | None = ..., /
) -> int: ...
def SendMessageTimeout(
    hwnd: int,
    message: int,
    wparam: ReadableBuffer | float | None,
    lparam: ReadableBuffer | float | None,
    flags: int,
    timeout: int,
    /,
) -> tuple[int, int]: ...
def PostMessage(
    hwnd: int | None, message: int, wparam: int | None = ..., lparam: ReadableBuffer | float | None = ..., /
) -> None: ...
def PostThreadMessage(threadId, message, wparam, lparam, /) -> None: ...
def ReplyMessage(result, /): ...
def ResetDC(hdc: int, devmode: _win32typing.PyDEVMODE | _win32typing.PyDEVMODEW, /) -> int: ...
def RegisterWindowMessage(name: str, /): ...
def DefWindowProc(
    hwnd: int | None, message: int, wparam: ReadableBuffer | float | None, lparam: ReadableBuffer | float | None, /
) -> int: ...
def EnumWindows(callback: Callable[[int, _T], object], extra: _T, /) -> None: ...
def EnumThreadWindows(dwThreadId, callback: Callable[[int, _T], object], extra: _T, /) -> None: ...
def EnumChildWindows(hwnd: int | None, callback: Callable[[int, _T], object], extra: _T, /) -> None: ...
def DialogBox(hInstance: int, TemplateName: _win32typing.PyResourceId, hWndParent: int, DialogFunc, InitParam: int = ..., /): ...
def DialogBoxParam(): ...
def DialogBoxIndirect(
    hInstance: int, controllist: _win32typing.PyDialogTemplate, hWndParent: int, DialogFunc, InitParam: int = ..., /
): ...
def DialogBoxIndirectParam(): ...
def CreateDialogIndirect(
    hInstance: int, controllist: _win32typing.PyDialogTemplate, hWndParent: int, DialogFunc, InitParam: int = ..., /
): ...
def EndDialog(hwnd: int, result, /) -> None: ...
def GetDlgItem(hDlg: int, IDDlgItem, /): ...
def GetDlgItemInt(hDlg: int, IDDlgItem, Signed, /) -> None: ...
def SetDlgItemInt(hDlg: int, IDDlgItem, Value, Signed, /) -> None: ...
def GetDlgCtrlID(hwnd: int, /): ...
def GetDlgItemText(hDlg: int, IDDlgItem, /) -> str: ...
def SetDlgItemText(hDlg: int, IDDlgItem, String, /) -> None: ...
def GetNextDlgTabItem(hDlg, hCtl, bPrevious, /): ...
def GetNextDlgGroupItem(hDlg, hCtl, bPrevious, /): ...
def SetWindowText() -> None: ...
def GetWindowText(hwnd: int, /) -> str: ...
def InitCommonControls() -> None: ...
def InitCommonControlsEx(flag, /) -> None: ...
def LoadCursor(hinstance, resid, /): ...
def SetCursor(hcursor, /): ...
def GetCursor(): ...
def GetCursorInfo() -> tuple[int, int, int, int]: ...
def CreateAcceleratorTable(accels: tuple[tuple[Incomplete, Incomplete, Incomplete], ...], /): ...
def LoadMenu(hinstance, resource_id: str, /): ...
def DestroyMenu() -> None: ...
def SetMenu(hwnd: int, hmenu, /) -> None: ...
def GetMenu(hwnd: int, /) -> int: ...
def LoadIcon(hinstance: int, resource_id_or_name: str | int, /) -> _win32typing.PyWNDCLASS: ...
def CopyIcon(hicon, /): ...
def DrawIcon(hDC, X, Y, hicon, /) -> None: ...
def DrawIconEx(
    hDC, xLeft, yTop, hIcon, cxWidth, cyWidth, istepIfAniCur, hbrFlickerFreeDraw: _win32typing.PyGdiHANDLE, diFlags, /
) -> None: ...
def CreateIconIndirect(iconinfo: _win32typing.PyICONINFO, /): ...
def CreateIconFromResource(bits: str, fIcon, ver: int = ..., /) -> int: ...
def LoadImage(hinst: int, name: str, type: int, cxDesired: int, cyDesired: int, fuLoad: int, /) -> _win32typing.PyGdiHANDLE: ...
def DeleteObject(handle: int | _win32typing.PyGdiHANDLE, /) -> None: ...
def BitBlt(
    hdcDest: int | _win32typing.PyGdiHANDLE,
    x: int,
    y: int,
    width: int,
    height: int,
    hdcSrc: int | _win32typing.PyGdiHANDLE | None,
    nXSrc: int,
    nYSrc: int,
    dwRop: int,
    /,
) -> None: ...
def StretchBlt(hdcDest, x, y, width, height, hdcSrc, nXSrc, nYSrc, nWidthSrc, nHeightSrc, dwRop, /) -> None: ...
def PatBlt(hdc: int, XLeft, YLeft, Width, Height, Rop, /) -> None: ...
def SetStretchBltMode(hdc: int, StretchMode, /): ...
def GetStretchBltMode(hdc: int, /): ...
def TransparentBlt(
    Dest: int,
    XOriginDest,
    YOriginDest,
    WidthDest,
    HeightDest,
    Src: int,
    XOriginSrc,
    YOriginSrc,
    WidthSrc,
    HeightSrc,
    Transparent,
    /,
) -> None: ...
def MaskBlt(
    Dest: int, XDest, YDest, Width, Height, Src: int, XSrc, YSrc, Mask: _win32typing.PyGdiHANDLE, xMask, yMask, Rop, /
) -> None: ...
def AlphaBlend(
    Dest: int,
    XOriginDest,
    YOriginDest,
    WidthDest,
    HeightDest,
    Src: int,
    XOriginSrc,
    YOriginSrc,
    WidthSrc,
    HeightSrc,
    blendFunction: _win32typing.PyBLENDFUNCTION,
    /,
) -> None: ...
def MessageBox(parent, text: str, caption: str, flags, /): ...
def MessageBeep(_type, /) -> None: ...
def CreateWindow(
    className: str | _win32typing.PyResourceId,
    windowTitle: str | None,
    style: int,
    x: int,
    y: int,
    width: int,
    height: int,
    parent: int,
    menu: int,
    hinstance: int,
    reserved: Incomplete | None,
    /,
) -> int: ...
def DestroyWindow(_hwnd: int, /) -> None: ...
def EnableWindow(hWnd: int, bEnable, /): ...
def FindWindow(ClassName: _win32typing.PyResourceId | str | None, WindowName: str | None, /) -> int: ...
def FindWindowEx(
    Parent: int | None, ChildAfter: int | None, ClassName: _win32typing.PyResourceId | str | None, WindowName: str | None, /
) -> int: ...
def DragAcceptFiles(hwnd: int, fAccept, /) -> None: ...
def DragDetect(hwnd: int, point: tuple[Incomplete, Incomplete], /) -> None: ...
def SetDoubleClickTime(newVal, /) -> None: ...
def GetDoubleClickTime(): ...
def HideCaret(hWnd: int, /) -> None: ...
def SetCaretPos(x, y, /) -> None: ...
def GetCaretPos() -> tuple[Incomplete, Incomplete]: ...
def ShowCaret(hWnd: int, /) -> None: ...
def ShowWindow(hWnd: int | None, cmdShow: int, /) -> int: ...
def IsWindowVisible(hwnd: int | None, /) -> int: ...
def IsWindowEnabled(hwnd: int | None, /) -> int: ...
def SetFocus(hwnd: int, /) -> None: ...
def GetFocus() -> None: ...
def UpdateWindow(hwnd: int, /) -> None: ...
def BringWindowToTop(hwnd: int, /) -> None: ...
def SetActiveWindow(hwnd: int, /): ...
def GetActiveWindow(): ...
def SetForegroundWindow(hwnd: int, /) -> None: ...
def GetForegroundWindow() -> int: ...
def GetClientRect(hwnd: int, /) -> tuple[int, int, int, int]: ...
def GetDC(hwnd: int, /): ...
def SaveDC(hdc: int, /): ...
def RestoreDC(hdc: int, SavedDC, /) -> None: ...
def DeleteDC(hdc: int | _win32typing.PyHANDLE, /) -> None: ...
def CreateCompatibleDC(dc: int | _win32typing.PyHANDLE | None, /) -> int: ...
def CreateCompatibleBitmap(hdc: int | _win32typing.PyHANDLE | None, width: int, height: int, /) -> _win32typing.PyGdiHANDLE: ...
def CreateBitmap(width: int, height: int, cPlanes: int, cBitsPerPixel: int, bitmap_bits: None, /) -> _win32typing.PyGdiHANDLE: ...
def SelectObject(hdc: int | _win32typing.PyHANDLE | None, object: int | _win32typing.PyHANDLE | None, /) -> int: ...
def GetCurrentObject(hdc: int, ObjectType, /) -> int: ...
def GetWindowRect(hwnd: int | _win32typing.PyHANDLE, /) -> tuple[int, int, int, int]: ...
def GetStockObject(Object, /) -> int: ...
def PostQuitMessage(rc: int, /) -> None: ...
def WaitMessage() -> None: ...
def SetWindowPos(hWnd: int, InsertAfter: int | None, X: int, Y: int, cx: int, cy: int, Flags: int, /) -> None: ...
def GetWindowPlacement(hwnd: int, /) -> tuple[int, int, tuple[int, int], tuple[int, int], tuple[int, int, int, int]]: ...
def SetWindowPlacement(hWnd: int, placement, /) -> None: ...
def RegisterClass(wndClass: _win32typing.PyWNDCLASS, /) -> _win32typing.PyResourceId: ...
def UnregisterClass(atom: _win32typing.PyResourceId, hinst: int, /) -> None: ...
def PumpMessages() -> None: ...
def PumpWaitingMessages(firstMessage: int = ..., lastMessage: int = ..., /) -> int: ...
def GetMessage(hwnd: int, _min, _max, /): ...
def TranslateMessage(msg, /): ...
def DispatchMessage(msg, /): ...
def TranslateAccelerator(hwnd: int, haccel, msg, /): ...
def PeekMessage(hwnd: int, filterMin, filterMax, removalOptions, /): ...
def Shell_NotifyIcon(Message: int, nid: _win32typing.PyNOTIFYICONDATA, /) -> None: ...
def GetSystemMenu(hwnd: int, bRevert, /): ...
def DrawMenuBar(hwnd: int, /) -> None: ...
def MoveWindow(hwnd: int, x: int, y: int, width: int, height: int, bRepaint: bool, /) -> None: ...
def CloseWindow() -> None: ...
def DeleteMenu(hmenu, position, flags, /) -> None: ...
def RemoveMenu(hmenu, position, flags, /) -> None: ...
def CreateMenu(): ...
def CreatePopupMenu(): ...
def TrackPopupMenu(hmenu, flags, x, y, reserved, hwnd: int, prcRect: _win32typing.PyRECT, /): ...
def CommDlgExtendedError(): ...
def ExtractIcon(hinstance, moduleName: str, index, /): ...
def ExtractIconEx(moduleName: str, index, numIcons: int = ..., /): ...
def DestroyIcon(hicon, /) -> None: ...
def GetIconInfo(hicon: int, /) -> _win32typing.PyICONINFO: ...
def ScreenToClient(hWnd: int, Point: tuple[Incomplete, Incomplete], /) -> tuple[Incomplete, Incomplete]: ...
def ClientToScreen(hWnd: int, Point: tuple[Incomplete, Incomplete], /) -> tuple[Incomplete, Incomplete]: ...
def PaintDesktop(hdc: int, /) -> None: ...
def RedrawWindow(hWnd: int, rcUpdate: tuple[int, int, int, int], hrgnUpdate: _win32typing.PyGdiHANDLE, flags, /) -> None: ...
def GetTextExtentPoint32(hdc: int, _str: str, /) -> tuple[Incomplete, Incomplete]: ...
def GetTextMetrics(): ...
def GetTextCharacterExtra(hdc: int, /): ...
def SetTextCharacterExtra(hdc: int, CharExtra, /): ...
def GetTextAlign(hdc: int, /): ...
def SetTextAlign(hdc: int, Mode, /): ...
def GetTextFace(hdc: int, /) -> str: ...
def GetMapMode(hdc: int, /): ...
def SetMapMode(hdc: int, MapMode, /): ...
def GetGraphicsMode(hdc: int, /): ...
def SetGraphicsMode(hdc: int, Mode, /): ...
def GetLayout(hdc: int, /): ...
def SetLayout(hdc: int, Layout, /): ...
def GetPolyFillMode(hdc: int, /): ...
def SetPolyFillMode(hdc: int, PolyFillMode, /): ...
def GetWorldTransform(hdc: int, /) -> _win32typing.PyXFORM: ...
def SetWorldTransform(hdc: int, Xform: _win32typing.PyXFORM, /) -> None: ...
def ModifyWorldTransform(hdc: int, Xform: _win32typing.PyXFORM, Mode, /) -> None: ...
def CombineTransform(xform1: _win32typing.PyXFORM, xform2: _win32typing.PyXFORM, /) -> _win32typing.PyXFORM: ...
def GetWindowOrgEx(hdc: int, /) -> tuple[Incomplete, Incomplete]: ...
def SetWindowOrgEx(hdc: int, X, Y, /) -> tuple[Incomplete, Incomplete]: ...
def GetViewportOrgEx(hdc: int, /) -> tuple[Incomplete, Incomplete]: ...
def SetViewportOrgEx(hdc: int, X, Y, /) -> tuple[Incomplete, Incomplete]: ...
def GetWindowExtEx(hdc: int, /) -> tuple[Incomplete, Incomplete]: ...
def SetWindowExtEx(hdc: int, XExtent, YExtent, /) -> tuple[Incomplete, Incomplete]: ...
def GetViewportExtEx(hdc: int, /) -> tuple[Incomplete, Incomplete]: ...
def SetViewportExtEx(hdc: int, XExtent, YExtent, /) -> tuple[Incomplete, Incomplete]: ...
def GradientFill(hdc, Vertex: tuple[_win32typing.PyTRIVERTEX, ...], Mesh, Mode, /) -> None: ...
def GetOpenFileName(OPENFILENAME: str, /): ...
def InsertMenuItem(hMenu, uItem, fByPosition, menuItem, /) -> None: ...
def SetMenuItemInfo(hMenu, uItem, fByPosition, menuItem, /) -> None: ...
def GetMenuItemInfo(hMenu: int, uItem: int, fByPosition: bool, menuItem: ReadableBuffer, /) -> None: ...
def GetMenuItemCount(hMenu: int | None, /) -> int: ...

# Actually returns a list of int|tuple, but lists don't support positional types
def GetMenuItemRect(hWnd: int | None, hMenu: int | None, uItem: int, /) -> tuple[int, tuple[int, int, int, int]]: ...
def GetMenuState(hMenu, uID, flags, /): ...
def SetMenuDefaultItem(hMenu, uItem, fByPos, /) -> None: ...
def GetMenuDefaultItem(hMenu, fByPos, flags, /): ...
def AppendMenu() -> None: ...
def InsertMenu() -> None: ...
def EnableMenuItem() -> None: ...
def CheckMenuItem(): ...
def GetSubMenu(hMenu, nPos, /): ...
def ModifyMenu(hMnu, uPosition, uFlags, uIDNewItem, newItem: str, /) -> None: ...
def GetMenuItemID(hMenu, nPos, /): ...
def SetMenuItemBitmaps(
    hMenu, uPosition, uFlags, hBitmapUnchecked: _win32typing.PyGdiHANDLE, hBitmapChecked: _win32typing.PyGdiHANDLE, /
) -> None: ...
def CheckMenuRadioItem(hMenu, idFirst, idLast, idCheck, uFlags, /) -> None: ...
def SetMenuInfo(hmenu, info, /) -> None: ...
def GetMenuInfo(hmenu: int, info: WriteableBuffer, /) -> None: ...
def DrawFocusRect(hDC: int, rc: tuple[int, int, int, int], /) -> None: ...
def DrawText(hDC: int, String, nCount, Rect: _win32typing.PyRECT, Format, /) -> tuple[Incomplete, _win32typing.PyRECT]: ...
def LineTo(hdc: int, XEnd, YEnd, /) -> None: ...
def Ellipse(hdc: int, LeftRect, TopRect, RightRect, BottomRect, /) -> None: ...
def Pie(hdc: int, LeftRect, TopRect, RightRect, BottomRect, XRadial1, YRadial1, XRadial2, YRadial2, /) -> None: ...
def Arc(hdc: int, LeftRect, TopRect, RightRect, BottomRect, XRadial1, YRadial1, XRadial2, YRadial2, /) -> None: ...
def ArcTo(hdc: int, LeftRect, TopRect, RightRect, BottomRect, XRadial1, YRadial1, XRadial2, YRadial2, /) -> None: ...
def AngleArc(hdc: int, Y, Y1, Radius, StartAngle: float, SweepAngle: float, /) -> None: ...
def Chord(hdc: int, LeftRect, TopRect, RightRect, BottomRect, XRadial1, YRadial1, XRadial2, YRadial2, /) -> None: ...
def ExtFloodFill(arg: int, XStart, YStart, Color, FillType, /) -> None: ...
def SetPixel(hdc: int, X, Y, Color, /): ...
def GetPixel(hdc: int, XPos, YPos, /): ...
def GetROP2(hdc: int, /): ...
def SetROP2(hdc: int, DrawMode, /): ...
def SetPixelV(hdc: int, X, Y, Color, /) -> None: ...
def MoveToEx(hdc: int, X, Y, /) -> tuple[Incomplete, Incomplete]: ...
def GetCurrentPositionEx(hdc: int, /) -> tuple[Incomplete, Incomplete]: ...
def GetArcDirection(hdc: int, /): ...
def SetArcDirection(hdc: int, ArcDirection, /): ...
def Polygon(hdc: int, Points: list[tuple[Incomplete, Incomplete]], /) -> None: ...
def Polyline(hdc: int, Points: list[tuple[Incomplete, Incomplete]], /) -> None: ...
def PolylineTo(hdc: int, Points: list[tuple[Incomplete, Incomplete]], /) -> None: ...
def PolyBezier(hdc: int, Points: list[tuple[Incomplete, Incomplete]], /) -> None: ...
def PolyBezierTo(hdc: int, Points: list[tuple[Incomplete, Incomplete]], /) -> None: ...
def PlgBlt(
    Dest: int,
    Point,
    Src: int,
    XSrc,
    YSrc,
    Width,
    Height,
    Mask: _win32typing.PyGdiHANDLE | None = ...,
    xMask: int = ...,
    yMask: int = ...,
    /,
) -> None: ...
def CreatePolygonRgn(Points: list[tuple[Incomplete, Incomplete]], PolyFillMode, /) -> _win32typing.PyGdiHANDLE: ...
def ExtTextOut(
    hdc: int, _int, _int1, _int2, rect: _win32typing.PyRECT, string, _tuple: tuple[tuple[Incomplete, Incomplete], ...], /
): ...
def GetTextColor(hdc, /): ...
def SetTextColor(hdc, color, /): ...
def GetBkMode(hdc: int, /): ...
def SetBkMode(hdc: int, BkMode, /): ...
def GetBkColor(hdc: int, /): ...
def SetBkColor(hdc: int, color, /): ...
def DrawEdge(hdc: int, rc: _win32typing.PyRECT, edge, Flags, /) -> _win32typing.PyRECT: ...
def FillRect(hDC: int, rc: _win32typing.PyRECT, hbr: _win32typing.PyGdiHANDLE, /) -> None: ...
def FillRgn(hdc: int, hrgn: _win32typing.PyGdiHANDLE, hbr: _win32typing.PyGdiHANDLE, /) -> None: ...
def PaintRgn(hdc: int, hrgn: _win32typing.PyGdiHANDLE, /) -> None: ...
def FrameRgn(hdc: int, hrgn, hbr, Width, Height, /) -> None: ...
def InvertRgn(hdc: int, hrgn, /) -> None: ...
def EqualRgn(SrcRgn1, SrcRgn2, /): ...
def PtInRegion(hrgn, X, Y, /): ...
def PtInRect(rect: tuple[int, int, int, int], point: tuple[Incomplete, Incomplete], /): ...
def RectInRegion(hrgn, rc: _win32typing.PyRECT, /): ...
def SetRectRgn(hrgn, LeftRect, TopRect, RightRect, BottomRect, /) -> None: ...
def CombineRgn(Dest, Src1, Src2, CombineMode, /): ...
def DrawAnimatedRects(hwnd: int, idAni, minCoords: _win32typing.PyRECT, restCoords: _win32typing.PyRECT, /) -> None: ...
def CreateSolidBrush(Color, /) -> _win32typing.PyGdiHANDLE: ...
def CreatePatternBrush(hbmp: _win32typing.PyGdiHANDLE, /) -> _win32typing.PyGdiHANDLE: ...
def CreateHatchBrush(Style, clrref, /) -> _win32typing.PyGdiHANDLE: ...
def CreatePen(PenStyle, Width, Color, /) -> _win32typing.PyGdiHANDLE: ...
def GetSysColor(Index, /): ...
def GetSysColorBrush(Index, /) -> _win32typing.PyGdiHANDLE: ...
def InvalidateRect(hWnd: int, Rect: _win32typing.PyRECT, Erase, /) -> None: ...
def FrameRect(hDC: int, rc: _win32typing.PyRECT, hbr: _win32typing.PyGdiHANDLE, /) -> None: ...
def InvertRect(hDC: int, rc: _win32typing.PyRECT, /) -> None: ...
def WindowFromDC(hDC: int, /) -> int: ...
def GetUpdateRgn(hWnd: int, hRgn: _win32typing.PyGdiHANDLE, Erase, /): ...
def GetWindowRgn(hWnd: int, hRgn: _win32typing.PyGdiHANDLE, /): ...
def SetWindowRgn(hWnd: int, hRgn: _win32typing.PyGdiHANDLE, Redraw, /) -> None: ...
def ValidateRgn(hWnd: int, hRgn: _win32typing.PyGdiHANDLE, /) -> None: ...
def InvalidateRgn(hWnd: int, hRgn: _win32typing.PyGdiHANDLE, Erase, /) -> None: ...
def GetRgnBox(hrgn: _win32typing.PyGdiHANDLE, /) -> tuple[Incomplete, _win32typing.PyRECT]: ...
def OffsetRgn(hrgn: _win32typing.PyGdiHANDLE, XOffset, YOffset, /): ...
def Rectangle(hdc: int, LeftRect, TopRect, RightRect, BottomRect, /) -> None: ...
def RoundRect(hdc: int, LeftRect, TopRect, RightRect, BottomRect, Width, Height, /) -> None: ...
def BeginPaint() -> tuple[Incomplete, Incomplete]: ...
def EndPaint(hwnd: int, ps, /) -> None: ...
def BeginPath(hdc: int, /) -> None: ...
def EndPath(hdc: int, /) -> None: ...
def AbortPath(hdc: int, /) -> None: ...
def CloseFigure(hdc: int, /) -> None: ...
def FlattenPath(hdc: int, /) -> None: ...
def FillPath(hdc: int, /) -> None: ...
def WidenPath(hdc: int, /) -> None: ...
def StrokePath(hdc: int, /) -> None: ...
def StrokeAndFillPath(hdc: int, /) -> None: ...
def GetMiterLimit(hdc: int, /) -> float: ...
def SetMiterLimit(hdc: int, NewLimit: float, /) -> float: ...
def PathToRegion(hdc: int, /) -> _win32typing.PyGdiHANDLE: ...
def GetPath(hdc: int, /) -> tuple[Incomplete, Incomplete]: ...
def CreateRoundRectRgn(LeftRect, TopRect, RightRect, BottomRect, WidthEllipse, HeightEllipse, /): ...
def CreateRectRgnIndirect(rc: _win32typing.PyRECT, /): ...
def CreateEllipticRgnIndirect(rc: _win32typing.PyRECT, /): ...
def CreateWindowEx(
    dwExStyle, className: str, windowTitle: str, style, x, y, width, height, parent, menu, hinstance, reserved, /
): ...
def GetParent(child: int, /) -> int: ...
def SetParent(child: int, child1: int | _win32typing.PyHANDLE | None, /) -> int: ...
def GetCursorPos() -> tuple[Incomplete, Incomplete]: ...
def GetDesktopWindow(): ...
def GetWindow(hWnd: int, uCmd: int, /) -> int: ...
def GetWindowDC(hWnd: int | _win32typing.PyHANDLE | None, /) -> int: ...
def IsIconic(hWnd: int, /) -> int: ...
def IsWindow(hWnd: int, /) -> int: ...
def IsChild(hWndParent: int, hWnd: int, /) -> int: ...
def ReleaseCapture() -> None: ...
def GetCapture(): ...
def SetCapture() -> None: ...
def ReleaseDC(hWnd: int | _win32typing.PyHANDLE | None, hDC: int | _win32typing.PyHANDLE | None, /) -> Literal[0, 1]: ...
def CreateCaret(hWnd: int, hBitmap: _win32typing.PyGdiHANDLE, nWidth, nHeight, /) -> None: ...
def DestroyCaret() -> None: ...
def ScrollWindowEx(
    hWnd: int, dx, dy, rcScroll: _win32typing.PyRECT, rcClip: _win32typing.PyRECT, hrgnUpdate, flags, /
) -> tuple[Incomplete, _win32typing.PyRECT]: ...
def SetScrollInfo(hwnd: int, nBar, scollInfo: _win32typing.PySCROLLINFO, bRedraw=..., /) -> None: ...
def GetScrollInfo(hwnd: int, nBar, mask, /) -> _win32typing.PySCROLLINFO: ...
def GetClassName(hwnd: int, /) -> str: ...
def WindowFromPoint(point: tuple[int, int], /) -> int: ...
def ChildWindowFromPoint(hwndParent: int, point: tuple[Incomplete, Incomplete], /): ...
def CreateDC(Driver: str, Device: str, InitData: _win32typing.PyDEVMODE, /): ...
def GetSaveFileNameW(
    hwndOwner: int | None = ...,
    hInstance: int | None = ...,
    Filter: Incomplete | None = ...,
    CustomFilter: Incomplete | None = ...,
    FilterIndex: int = ...,
    File: Incomplete | None = ...,
    MaxFile: int = ...,
    InitialDir: Incomplete | None = ...,
    Title: Incomplete | None = ...,
    Flags: int = ...,
    DefExt: Incomplete | None = ...,
    TemplateName: _win32typing.PyResourceId | None = ...,
    /,
) -> tuple[Incomplete, Incomplete, Incomplete]: ...
def GetOpenFileNameW(
    hwndOwner: int | None = ...,
    hInstance: int | None = ...,
    Filter: Incomplete | None = ...,
    CustomFilter: Incomplete | None = ...,
    FilterIndex: int = ...,
    File: Incomplete | None = ...,
    MaxFile: int = ...,
    InitialDir: Incomplete | None = ...,
    Title: Incomplete | None = ...,
    Flags: int = ...,
    DefExt: Incomplete | None = ...,
    TemplateName: _win32typing.PyResourceId | None = ...,
) -> tuple[Incomplete, Incomplete, Incomplete]: ...
def SystemParametersInfo(Action, Param: Incomplete | None = ..., WinIni: int = ...) -> None: ...
def SetLayeredWindowAttributes(hwnd: int, Key, Alpha, Flags) -> None: ...
def GetLayeredWindowAttributes(hwnd: int) -> tuple[Incomplete, Incomplete, Incomplete]: ...
def UpdateLayeredWindow(
    hwnd: int,
    hdcDst: int | None = ...,
    ptDst: tuple[Incomplete, Incomplete] | None = ...,
    size: tuple[Incomplete, Incomplete] | None = ...,
    hdcSrc: Incomplete | None = ...,
    ptSrc: tuple[Incomplete, Incomplete] | None = ...,
    Key: int = ...,
    blend: tuple[int, int, int, int] = ...,
    Flags: int = ...,
) -> None: ...
def AnimateWindow(hwnd: int, Time, Flags) -> None: ...
def CreateBrushIndirect(lb: _win32typing.PyLOGBRUSH, /) -> _win32typing.PyGdiHANDLE: ...
def ExtCreatePen(PenStyle, Width, lb: _win32typing.PyLOGBRUSH, Style: tuple[Incomplete, ...] | None = ..., /) -> int: ...
def DrawTextW(hDC: int, String: str, Count, Rect: _win32typing.PyRECT, Format) -> tuple[Incomplete, _win32typing.PyRECT]: ...
def EnumPropsEx(hWnd: int, EnumFunc, Param, /) -> None: ...
def RegisterDeviceNotification(handle: int, _filter, flags, /) -> _win32typing.PyHDEVNOTIFY: ...
def UnregisterDeviceNotification() -> None: ...
def RegisterHotKey(hWnd: int, _id, Modifiers, vk, /) -> None: ...
def GetAncestor(hwnd: int, gaFlags: int, /) -> int: ...
def GetTopWindow(hWnd: int | None, /) -> int: ...
def ChildWindowFromPointEx(*args): ...  # incomplete
def CreateDialogIndirectParam(*args): ...  # incomplete
def DestroyAcceleratorTable(*args): ...  # incomplete
def Edit_GetLine(*args): ...  # incomplete
def GetModuleHandle(lpModuleName: str | None, /) -> int: ...
def GetWindowTextLength(*args): ...  # incomplete
def HIWORD(*args): ...  # incomplete
def ImageList_Add(*args): ...  # incomplete
def ImageList_Create(*args): ...  # incomplete
def ImageList_Destroy(*args): ...  # incomplete
def ImageList_Draw(*args): ...  # incomplete
def ImageList_DrawEx(*args): ...  # incomplete
def ImageList_GetIcon(*args): ...  # incomplete
def ImageList_GetImageCount(*args): ...  # incomplete
def ImageList_LoadBitmap(*args): ...  # incomplete
def ImageList_LoadImage(*args): ...  # incomplete
def ImageList_Remove(*args): ...  # incomplete
def ImageList_Replace(*args): ...  # incomplete
def ImageList_ReplaceIcon(*args): ...  # incomplete
def ImageList_SetBkColor(*args): ...  # incomplete
def ImageList_SetOverlayImage(*args): ...  # incomplete
def LOWORD(*args): ...  # incomplete
def ListView_SortItems(*args): ...  # incomplete
def ListView_SortItemsEx(*args): ...  # incomplete
def ValidateRect(*args): ...  # incomplete
def WNDCLASS() -> _win32typing.PyWNDCLASS: ...
def lpstr(*args): ...  # incomplete

CLR_NONE: int
ILC_COLOR: int
ILC_COLOR16: int
ILC_COLOR24: int
ILC_COLOR32: int
ILC_COLOR4: int
ILC_COLOR8: int
ILC_COLORDDB: int
ILC_MASK: int
ILD_BLEND: int
ILD_BLEND25: int
ILD_BLEND50: int
ILD_FOCUS: int
ILD_MASK: int
ILD_NORMAL: int
ILD_SELECTED: int
ILD_TRANSPARENT: int
IMAGE_BITMAP: int
IMAGE_CURSOR: int
IMAGE_ICON: int
LR_CREATEDIBSECTION: int
LR_DEFAULTCOLOR: int
LR_DEFAULTSIZE: int
LR_LOADFROMFILE: int
LR_LOADMAP3DCOLORS: int
LR_LOADTRANSPARENT: int
LR_MONOCHROME: int
LR_SHARED: int
LR_VGACOLOR: int
NIF_ICON: int
NIF_INFO: int
NIF_MESSAGE: int
NIF_STATE: int
NIF_TIP: int
NIIF_ERROR: int
NIIF_ICON_MASK: int
NIIF_INFO: int
NIIF_NONE: int
NIIF_NOSOUND: int
NIIF_WARNING: int
NIM_ADD: int
NIM_DELETE: int
NIM_MODIFY: int
NIM_SETVERSION: int
TPM_BOTTOMALIGN: int
TPM_CENTERALIGN: int
TPM_LEFTALIGN: int
TPM_LEFTBUTTON: int
TPM_NONOTIFY: int
TPM_RETURNCMD: int
TPM_RIGHTALIGN: int
TPM_RIGHTBUTTON: int
TPM_TOPALIGN: int
TPM_VCENTERALIGN: int
UNICODE: Literal[True]
dllhandle: int



from _typeshed import Incomplete

from win32com.server import policy as policy
from win32com.server.exception import COMException as COMException

def wrap(ob, iid: Incomplete | None = ..., usePolicy: Incomplete | None = ..., useDispatcher: Incomplete | None = ...): ...
def unwrap(ob): ...

class ListEnumerator:
    index: Incomplete
    def __init__(self, data, index: int = ..., iid=...) -> None: ...
    def Next(self, count): ...
    def Skip(self, count) -> None: ...
    def Reset(self) -> None: ...
    def Clone(self): ...

class ListEnumeratorGateway(ListEnumerator):
    def Next(self, count): ...

def NewEnum(seq, cls=..., iid=..., usePolicy: Incomplete | None = ..., useDispatcher: Incomplete | None = ...): ...

class Collection:
    data: Incomplete
    def __init__(self, data: Incomplete | None = ..., readOnly: int = ...) -> None: ...
    def Item(self, *args): ...
    def Count(self): ...
    def Add(self, value) -> None: ...
    def Remove(self, index) -> None: ...
    def Insert(self, index, value) -> None: ...

def NewCollection(seq, cls=...): ...

class FileStream:
    file: Incomplete
    def __init__(self, file) -> None: ...
    def Read(self, amount): ...
    def Write(self, data): ...
    def Clone(self): ...
    def CopyTo(self, dest, cb): ...
    def Seek(self, offset, origin): ...



CNLEN: int
LM20_CNLEN: int
DNLEN: int
LM20_DNLEN: int
UNCLEN: int
LM20_UNCLEN: int
NNLEN: int
LM20_NNLEN: int
RMLEN: int
LM20_RMLEN: int
SNLEN: int
LM20_SNLEN: int
STXTLEN: int
LM20_STXTLEN: int
PATHLEN: int
LM20_PATHLEN: int
DEVLEN: int
LM20_DEVLEN: int
EVLEN: int
UNLEN: int
LM20_UNLEN: int
GNLEN: int
LM20_GNLEN: int
PWLEN: int
LM20_PWLEN: int
SHPWLEN: int
CLTYPE_LEN: int
MAXCOMMENTSZ: int
LM20_MAXCOMMENTSZ: int
QNLEN: int
LM20_QNLEN: int
ALERTSZ: int
NETBIOS_NAME_LEN: int
CRYPT_KEY_LEN: int
CRYPT_TXT_LEN: int
ENCRYPTED_PWLEN: int
SESSION_PWLEN: int
SESSION_CRYPT_KLEN: int
PARMNUM_ALL: int
PARM_ERROR_NONE: int
PARMNUM_BASE_INFOLEVEL: int
NULL: int
PLATFORM_ID_DOS: int
PLATFORM_ID_OS2: int
PLATFORM_ID_NT: int
PLATFORM_ID_OSF: int
PLATFORM_ID_VMS: int
MAX_LANMAN_MESSAGE_ID: int
UF_SCRIPT: int
UF_ACCOUNTDISABLE: int
UF_HOMEDIR_REQUIRED: int
UF_LOCKOUT: int
UF_PASSWD_NOTREQD: int
UF_PASSWD_CANT_CHANGE: int
UF_TEMP_DUPLICATE_ACCOUNT: int
UF_NORMAL_ACCOUNT: int
UF_INTERDOMAIN_TRUST_ACCOUNT: int
UF_WORKSTATION_TRUST_ACCOUNT: int
UF_SERVER_TRUST_ACCOUNT: int
UF_MACHINE_ACCOUNT_MASK: int
UF_ACCOUNT_TYPE_MASK: int
UF_DONT_EXPIRE_PASSWD: int
UF_MNS_LOGON_ACCOUNT: int
UF_SETTABLE_BITS: int
FILTER_TEMP_DUPLICATE_ACCOUNT: int
FILTER_NORMAL_ACCOUNT: int
FILTER_INTERDOMAIN_TRUST_ACCOUNT: int
FILTER_WORKSTATION_TRUST_ACCOUNT: int
FILTER_SERVER_TRUST_ACCOUNT: int
LG_INCLUDE_INDIRECT: int
AF_OP_PRINT: int
AF_OP_COMM: int
AF_OP_SERVER: int
AF_OP_ACCOUNTS: int
AF_SETTABLE_BITS: int
UAS_ROLE_STANDALONE: int
UAS_ROLE_MEMBER: int
UAS_ROLE_BACKUP: int
UAS_ROLE_PRIMARY: int
USER_NAME_PARMNUM: int
USER_PASSWORD_PARMNUM: int
USER_PASSWORD_AGE_PARMNUM: int
USER_PRIV_PARMNUM: int
USER_HOME_DIR_PARMNUM: int
USER_COMMENT_PARMNUM: int
USER_FLAGS_PARMNUM: int
USER_SCRIPT_PATH_PARMNUM: int
USER_AUTH_FLAGS_PARMNUM: int
USER_FULL_NAME_PARMNUM: int
USER_USR_COMMENT_PARMNUM: int
USER_PARMS_PARMNUM: int
USER_WORKSTATIONS_PARMNUM: int
USER_LAST_LOGON_PARMNUM: int
USER_LAST_LOGOFF_PARMNUM: int
USER_ACCT_EXPIRES_PARMNUM: int
USER_MAX_STORAGE_PARMNUM: int
USER_UNITS_PER_WEEK_PARMNUM: int
USER_LOGON_HOURS_PARMNUM: int
USER_PAD_PW_COUNT_PARMNUM: int
USER_NUM_LOGONS_PARMNUM: int
USER_LOGON_SERVER_PARMNUM: int
USER_COUNTRY_CODE_PARMNUM: int
USER_CODE_PAGE_PARMNUM: int
USER_PRIMARY_GROUP_PARMNUM: int
USER_PROFILE: int
USER_PROFILE_PARMNUM: int
USER_HOME_DIR_DRIVE_PARMNUM: int
USER_NAME_INFOLEVEL: int
USER_PASSWORD_INFOLEVEL: int
USER_PASSWORD_AGE_INFOLEVEL: int
USER_PRIV_INFOLEVEL: int
USER_HOME_DIR_INFOLEVEL: int
USER_COMMENT_INFOLEVEL: int
USER_FLAGS_INFOLEVEL: int
USER_SCRIPT_PATH_INFOLEVEL: int
USER_AUTH_FLAGS_INFOLEVEL: int
USER_FULL_NAME_INFOLEVEL: int
USER_USR_COMMENT_INFOLEVEL: int
USER_PARMS_INFOLEVEL: int
USER_WORKSTATIONS_INFOLEVEL: int
USER_LAST_LOGON_INFOLEVEL: int
USER_LAST_LOGOFF_INFOLEVEL: int
USER_ACCT_EXPIRES_INFOLEVEL: int
USER_MAX_STORAGE_INFOLEVEL: int
USER_UNITS_PER_WEEK_INFOLEVEL: int
USER_LOGON_HOURS_INFOLEVEL: int
USER_PAD_PW_COUNT_INFOLEVEL: int
USER_NUM_LOGONS_INFOLEVEL: int
USER_LOGON_SERVER_INFOLEVEL: int
USER_COUNTRY_CODE_INFOLEVEL: int
USER_CODE_PAGE_INFOLEVEL: int
USER_PRIMARY_GROUP_INFOLEVEL: int
USER_HOME_DIR_DRIVE_INFOLEVEL: int
NULL_USERSETINFO_PASSWD: str
UNITS_PER_DAY: int
UNITS_PER_WEEK: int
USER_PRIV_MASK: int
USER_PRIV_GUEST: int
USER_PRIV_USER: int
USER_PRIV_ADMIN: int
MAX_PASSWD_LEN: int
DEF_MIN_PWLEN: int
DEF_PWUNIQUENESS: int
DEF_MAX_PWHIST: int
DEF_MAX_BADPW: int
VALIDATED_LOGON: int
PASSWORD_EXPIRED: int
NON_VALIDATED_LOGON: int
VALID_LOGOFF: int
MODALS_MIN_PASSWD_LEN_PARMNUM: int
MODALS_MAX_PASSWD_AGE_PARMNUM: int
MODALS_MIN_PASSWD_AGE_PARMNUM: int
MODALS_FORCE_LOGOFF_PARMNUM: int
MODALS_PASSWD_HIST_LEN_PARMNUM: int
MODALS_ROLE_PARMNUM: int
MODALS_PRIMARY_PARMNUM: int
MODALS_DOMAIN_NAME_PARMNUM: int
MODALS_DOMAIN_ID_PARMNUM: int
MODALS_LOCKOUT_DURATION_PARMNUM: int
MODALS_LOCKOUT_OBSERVATION_WINDOW_PARMNUM: int
MODALS_LOCKOUT_THRESHOLD_PARMNUM: int
MODALS_MIN_PASSWD_LEN_INFOLEVEL: int
MODALS_MAX_PASSWD_AGE_INFOLEVEL: int
MODALS_MIN_PASSWD_AGE_INFOLEVEL: int
MODALS_FORCE_LOGOFF_INFOLEVEL: int
MODALS_PASSWD_HIST_LEN_INFOLEVEL: int
MODALS_ROLE_INFOLEVEL: int
MODALS_PRIMARY_INFOLEVEL: int
MODALS_DOMAIN_NAME_INFOLEVEL: int
MODALS_DOMAIN_ID_INFOLEVEL: int
GROUPIDMASK: int
GROUP_ALL_PARMNUM: int
GROUP_NAME_PARMNUM: int
GROUP_COMMENT_PARMNUM: int
GROUP_ATTRIBUTES_PARMNUM: int
GROUP_ALL_INFOLEVEL: int
GROUP_NAME_INFOLEVEL: int
GROUP_COMMENT_INFOLEVEL: int
GROUP_ATTRIBUTES_INFOLEVEL: int
LOCALGROUP_NAME_PARMNUM: int
LOCALGROUP_COMMENT_PARMNUM: int
MAXPERMENTRIES: int
ACCESS_NONE: int
ACCESS_READ: int
ACCESS_WRITE: int
ACCESS_CREATE: int
ACCESS_EXEC: int
ACCESS_DELETE: int
ACCESS_ATRIB: int
ACCESS_PERM: int
ACCESS_GROUP: int
ACCESS_AUDIT: int
ACCESS_SUCCESS_OPEN: int
ACCESS_SUCCESS_WRITE: int
ACCESS_SUCCESS_DELETE: int
ACCESS_SUCCESS_ACL: int
ACCESS_SUCCESS_MASK: int
ACCESS_FAIL_OPEN: int
ACCESS_FAIL_WRITE: int
ACCESS_FAIL_DELETE: int
ACCESS_FAIL_ACL: int
ACCESS_FAIL_MASK: int
ACCESS_FAIL_SHIFT: int
ACCESS_RESOURCE_NAME_PARMNUM: int
ACCESS_ATTR_PARMNUM: int
ACCESS_COUNT_PARMNUM: int
ACCESS_RESOURCE_NAME_INFOLEVEL: int
ACCESS_ATTR_INFOLEVEL: int
ACCESS_COUNT_INFOLEVEL: int
ACCESS_LETTERS: str
NETLOGON_CONTROL_QUERY: int
NETLOGON_CONTROL_REPLICATE: int
NETLOGON_CONTROL_SYNCHRONIZE: int
NETLOGON_CONTROL_PDC_REPLICATE: int
NETLOGON_CONTROL_REDISCOVER: int
NETLOGON_CONTROL_TC_QUERY: int
NETLOGON_CONTROL_TRANSPORT_NOTIFY: int
NETLOGON_CONTROL_FIND_USER: int
NETLOGON_CONTROL_UNLOAD_NETLOGON_DLL: int
NETLOGON_CONTROL_BACKUP_CHANGE_LOG: int
NETLOGON_CONTROL_TRUNCATE_LOG: int
NETLOGON_CONTROL_SET_DBFLAG: int
NETLOGON_CONTROL_BREAKPOINT: int
NETLOGON_REPLICATION_NEEDED: int
NETLOGON_REPLICATION_IN_PROGRESS: int
NETLOGON_FULL_SYNC_REPLICATION: int
NETLOGON_REDO_NEEDED: int

def TEXT(x: str) -> str: ...

MAX_PREFERRED_LENGTH: int
PARM_ERROR_UNKNOWN: int
MESSAGE_FILENAME: str
OS2MSG_FILENAME: str
HELP_MSG_FILENAME: str
BACKUP_MSG_FILENAME: str
TIMEQ_FOREVER: int
USER_MAXSTORAGE_UNLIMITED: int
USER_NO_LOGOFF: int
DEF_MAX_PWAGE: int
DEF_MIN_PWAGE: int
DEF_FORCE_LOGOFF: int
ONE_DAY: int
GROUP_SPECIALGRP_USERS: str
GROUP_SPECIALGRP_ADMINS: str
GROUP_SPECIALGRP_GUESTS: str
GROUP_SPECIALGRP_LOCAL: str
ACCESS_ALL: int
SV_PLATFORM_ID_OS2: int
SV_PLATFORM_ID_NT: int
MAJOR_VERSION_MASK: int
SV_TYPE_WORKSTATION: int
SV_TYPE_SERVER: int
SV_TYPE_SQLSERVER: int
SV_TYPE_DOMAIN_CTRL: int
SV_TYPE_DOMAIN_BAKCTRL: int
SV_TYPE_TIME_SOURCE: int
SV_TYPE_AFP: int
SV_TYPE_NOVELL: int
SV_TYPE_DOMAIN_MEMBER: int
SV_TYPE_PRINTQ_SERVER: int
SV_TYPE_DIALIN_SERVER: int
SV_TYPE_XENIX_SERVER: int
SV_TYPE_SERVER_UNIX: int
SV_TYPE_NT: int
SV_TYPE_WFW: int
SV_TYPE_SERVER_MFPN: int
SV_TYPE_SERVER_NT: int
SV_TYPE_POTENTIAL_BROWSER: int
SV_TYPE_BACKUP_BROWSER: int
SV_TYPE_MASTER_BROWSER: int
SV_TYPE_DOMAIN_MASTER: int
SV_TYPE_SERVER_OSF: int
SV_TYPE_SERVER_VMS: int
SV_TYPE_WINDOWS: int
SV_TYPE_DFS: int
SV_TYPE_CLUSTER_NT: int
SV_TYPE_DCE: int
SV_TYPE_ALTERNATE_XPORT: int
SV_TYPE_DOMAIN_ENUM: int
SV_TYPE_ALL: int
SV_NODISC: int
SV_USERSECURITY: int
SV_SHARESECURITY: int
SV_HIDDEN: int
SV_VISIBLE: int
SV_PLATFORM_ID_PARMNUM: int
SV_NAME_PARMNUM: int
SV_VERSION_MAJOR_PARMNUM: int
SV_VERSION_MINOR_PARMNUM: int
SV_TYPE_PARMNUM: int
SV_COMMENT_PARMNUM: int
SV_USERS_PARMNUM: int
SV_DISC_PARMNUM: int
SV_HIDDEN_PARMNUM: int
SV_ANNOUNCE_PARMNUM: int
SV_ANNDELTA_PARMNUM: int
SV_USERPATH_PARMNUM: int
SV_ALERTS_PARMNUM: int
SV_SECURITY_PARMNUM: int
SV_NUMADMIN_PARMNUM: int
SV_LANMASK_PARMNUM: int
SV_GUESTACC_PARMNUM: int
SV_CHDEVQ_PARMNUM: int
SV_CHDEVJOBS_PARMNUM: int
SV_CONNECTIONS_PARMNUM: int
SV_SHARES_PARMNUM: int
SV_OPENFILES_PARMNUM: int
SV_SESSREQS_PARMNUM: int
SV_ACTIVELOCKS_PARMNUM: int
SV_NUMREQBUF_PARMNUM: int
SV_NUMBIGBUF_PARMNUM: int
SV_NUMFILETASKS_PARMNUM: int
SV_ALERTSCHED_PARMNUM: int
SV_ERRORALERT_PARMNUM: int
SV_LOGONALERT_PARMNUM: int
SV_ACCESSALERT_PARMNUM: int
SV_DISKALERT_PARMNUM: int
SV_NETIOALERT_PARMNUM: int
SV_MAXAUDITSZ_PARMNUM: int
SV_SRVHEURISTICS_PARMNUM: int
SV_SESSOPENS_PARMNUM: int
SV_SESSVCS_PARMNUM: int
SV_OPENSEARCH_PARMNUM: int
SV_SIZREQBUF_PARMNUM: int
SV_INITWORKITEMS_PARMNUM: int
SV_MAXWORKITEMS_PARMNUM: int
SV_RAWWORKITEMS_PARMNUM: int
SV_IRPSTACKSIZE_PARMNUM: int
SV_MAXRAWBUFLEN_PARMNUM: int
SV_SESSUSERS_PARMNUM: int
SV_SESSCONNS_PARMNUM: int
SV_MAXNONPAGEDMEMORYUSAGE_PARMNUM: int
SV_MAXPAGEDMEMORYUSAGE_PARMNUM: int
SV_ENABLESOFTCOMPAT_PARMNUM: int
SV_ENABLEFORCEDLOGOFF_PARMNUM: int
SV_TIMESOURCE_PARMNUM: int
SV_ACCEPTDOWNLEVELAPIS_PARMNUM: int
SV_LMANNOUNCE_PARMNUM: int
SV_DOMAIN_PARMNUM: int
SV_MAXCOPYREADLEN_PARMNUM: int
SV_MAXCOPYWRITELEN_PARMNUM: int
SV_MINKEEPSEARCH_PARMNUM: int
SV_MAXKEEPSEARCH_PARMNUM: int
SV_MINKEEPCOMPLSEARCH_PARMNUM: int
SV_MAXKEEPCOMPLSEARCH_PARMNUM: int
SV_THREADCOUNTADD_PARMNUM: int
SV_NUMBLOCKTHREADS_PARMNUM: int
SV_SCAVTIMEOUT_PARMNUM: int
SV_MINRCVQUEUE_PARMNUM: int
SV_MINFREEWORKITEMS_PARMNUM: int
SV_XACTMEMSIZE_PARMNUM: int
SV_THREADPRIORITY_PARMNUM: int
SV_MAXMPXCT_PARMNUM: int
SV_OPLOCKBREAKWAIT_PARMNUM: int
SV_OPLOCKBREAKRESPONSEWAIT_PARMNUM: int
SV_ENABLEOPLOCKS_PARMNUM: int
SV_ENABLEOPLOCKFORCECLOSE_PARMNUM: int
SV_ENABLEFCBOPENS_PARMNUM: int
SV_ENABLERAW_PARMNUM: int
SV_ENABLESHAREDNETDRIVES_PARMNUM: int
SV_MINFREECONNECTIONS_PARMNUM: int
SV_MAXFREECONNECTIONS_PARMNUM: int
SV_INITSESSTABLE_PARMNUM: int
SV_INITCONNTABLE_PARMNUM: int
SV_INITFILETABLE_PARMNUM: int
SV_INITSEARCHTABLE_PARMNUM: int
SV_ALERTSCHEDULE_PARMNUM: int
SV_ERRORTHRESHOLD_PARMNUM: int
SV_NETWORKERRORTHRESHOLD_PARMNUM: int
SV_DISKSPACETHRESHOLD_PARMNUM: int
SV_MAXLINKDELAY_PARMNUM: int
SV_MINLINKTHROUGHPUT_PARMNUM: int
SV_LINKINFOVALIDTIME_PARMNUM: int
SV_SCAVQOSINFOUPDATETIME_PARMNUM: int
SV_MAXWORKITEMIDLETIME_PARMNUM: int
SV_MAXRAWWORKITEMS_PARMNUM: int
SV_PRODUCTTYPE_PARMNUM: int
SV_SERVERSIZE_PARMNUM: int
SV_CONNECTIONLESSAUTODISC_PARMNUM: int
SV_SHARINGVIOLATIONRETRIES_PARMNUM: int
SV_SHARINGVIOLATIONDELAY_PARMNUM: int
SV_MAXGLOBALOPENSEARCH_PARMNUM: int
SV_REMOVEDUPLICATESEARCHES_PARMNUM: int
SV_LOCKVIOLATIONRETRIES_PARMNUM: int
SV_LOCKVIOLATIONOFFSET_PARMNUM: int
SV_LOCKVIOLATIONDELAY_PARMNUM: int
SV_MDLREADSWITCHOVER_PARMNUM: int
SV_CACHEDOPENLIMIT_PARMNUM: int
SV_CRITICALTHREADS_PARMNUM: int
SV_RESTRICTNULLSESSACCESS_PARMNUM: int
SV_ENABLEWFW311DIRECTIPX_PARMNUM: int
SV_OTHERQUEUEAFFINITY_PARMNUM: int
SV_QUEUESAMPLESECS_PARMNUM: int
SV_BALANCECOUNT_PARMNUM: int
SV_PREFERREDAFFINITY_PARMNUM: int
SV_MAXFREERFCBS_PARMNUM: int
SV_MAXFREEMFCBS_PARMNUM: int
SV_MAXFREELFCBS_PARMNUM: int
SV_MAXFREEPAGEDPOOLCHUNKS_PARMNUM: int
SV_MINPAGEDPOOLCHUNKSIZE_PARMNUM: int
SV_MAXPAGEDPOOLCHUNKSIZE_PARMNUM: int
SV_SENDSFROMPREFERREDPROCESSOR_PARMNUM: int
SV_MAXTHREADSPERQUEUE_PARMNUM: int
SV_CACHEDDIRECTORYLIMIT_PARMNUM: int
SV_MAXCOPYLENGTH_PARMNUM: int
SV_ENABLEBULKTRANSFER_PARMNUM: int
SV_ENABLECOMPRESSION_PARMNUM: int
SV_AUTOSHAREWKS_PARMNUM: int
SV_AUTOSHARESERVER_PARMNUM: int
SV_ENABLESECURITYSIGNATURE_PARMNUM: int
SV_REQUIRESECURITYSIGNATURE_PARMNUM: int
SV_MINCLIENTBUFFERSIZE_PARMNUM: int
SV_CONNECTIONNOSESSIONSTIMEOUT_PARMNUM: int
SVI1_NUM_ELEMENTS: int
SVI2_NUM_ELEMENTS: int
SVI3_NUM_ELEMENTS: int
SW_AUTOPROF_LOAD_MASK: int
SW_AUTOPROF_SAVE_MASK: int
SV_MAX_SRV_HEUR_LEN: int
SV_USERS_PER_LICENSE: int
SVTI2_REMAP_PIPE_NAMES: int
SHARE_NETNAME_PARMNUM: int
SHARE_TYPE_PARMNUM: int
SHARE_REMARK_PARMNUM: int
SHARE_PERMISSIONS_PARMNUM: int
SHARE_MAX_USES_PARMNUM: int
SHARE_CURRENT_USES_PARMNUM: int
SHARE_PATH_PARMNUM: int
SHARE_PASSWD_PARMNUM: int
SHARE_FILE_SD_PARMNUM: int
SHI1_NUM_ELEMENTS: int
SHI2_NUM_ELEMENTS: int
STYPE_DISKTREE: int
STYPE_PRINTQ: int
STYPE_DEVICE: int
STYPE_IPC: int
STYPE_SPECIAL: int
SHI1005_FLAGS_DFS: int
SHI1005_FLAGS_DFS_ROOT: int
COW_PERMACHINE: int
COW_PERUSER: int
CSC_CACHEABLE: int
CSC_NOFLOWOPS: int
CSC_AUTO_INWARD: int
CSC_AUTO_OUTWARD: int
SHI1005_VALID_FLAGS_SET: int
SHI1007_VALID_FLAGS_SET: int
SESS_GUEST: int
SESS_NOENCRYPTION: int
SESI1_NUM_ELEMENTS: int
SESI2_NUM_ELEMENTS: int
PERM_FILE_READ: int
PERM_FILE_WRITE: int
PERM_FILE_CREATE: int
WNNC_NET_MSNET: int
WNNC_NET_LANMAN: int
WNNC_NET_NETWARE: int
WNNC_NET_VINES: int
WNNC_NET_10NET: int
WNNC_NET_LOCUS: int
WNNC_NET_SUN_PC_NFS: int
WNNC_NET_LANSTEP: int
WNNC_NET_9TILES: int
WNNC_NET_LANTASTIC: int
WNNC_NET_AS400: int
WNNC_NET_FTP_NFS: int
WNNC_NET_PATHWORKS: int
WNNC_NET_LIFENET: int
WNNC_NET_POWERLAN: int
WNNC_NET_BWNFS: int
WNNC_NET_COGENT: int
WNNC_NET_FARALLON: int
WNNC_NET_APPLETALK: int
WNNC_NET_INTERGRAPH: int
WNNC_NET_SYMFONET: int
WNNC_NET_CLEARCASE: int
WNNC_NET_FRONTIER: int
WNNC_NET_BMC: int
WNNC_NET_DCE: int
WNNC_NET_DECORB: int
WNNC_NET_PROTSTOR: int
WNNC_NET_FJ_REDIR: int
WNNC_NET_DISTINCT: int
WNNC_NET_TWINS: int
WNNC_NET_RDR2SAMPLE: int
RESOURCE_CONNECTED: int
RESOURCE_GLOBALNET: int
RESOURCE_REMEMBERED: int
RESOURCE_RECENT: int
RESOURCE_CONTEXT: int
RESOURCETYPE_ANY: int
RESOURCETYPE_DISK: int
RESOURCETYPE_PRINT: int
RESOURCETYPE_RESERVED: int
RESOURCETYPE_UNKNOWN: int
RESOURCEUSAGE_CONNECTABLE: int
RESOURCEUSAGE_CONTAINER: int
RESOURCEUSAGE_NOLOCALDEVICE: int
RESOURCEUSAGE_SIBLING: int
RESOURCEUSAGE_ATTACHED: int
RESOURCEUSAGE_ALL: int
RESOURCEUSAGE_RESERVED: int
RESOURCEDISPLAYTYPE_GENERIC: int
RESOURCEDISPLAYTYPE_DOMAIN: int
RESOURCEDISPLAYTYPE_SERVER: int
RESOURCEDISPLAYTYPE_SHARE: int
RESOURCEDISPLAYTYPE_FILE: int
RESOURCEDISPLAYTYPE_GROUP: int
RESOURCEDISPLAYTYPE_NETWORK: int
RESOURCEDISPLAYTYPE_ROOT: int
RESOURCEDISPLAYTYPE_SHAREADMIN: int
RESOURCEDISPLAYTYPE_DIRECTORY: int
RESOURCEDISPLAYTYPE_TREE: int
RESOURCEDISPLAYTYPE_NDSCONTAINER: int
NETPROPERTY_PERSISTENT: int
CONNECT_UPDATE_PROFILE: int
CONNECT_UPDATE_RECENT: int
CONNECT_TEMPORARY: int
CONNECT_INTERACTIVE: int
CONNECT_PROMPT: int
CONNECT_NEED_DRIVE: int
CONNECT_REFCOUNT: int
CONNECT_REDIRECT: int
CONNECT_LOCALDRIVE: int
CONNECT_CURRENT_MEDIA: int
CONNECT_DEFERRED: int
CONNECT_RESERVED: int
CONNDLG_RO_PATH: int
CONNDLG_CONN_POINT: int
CONNDLG_USE_MRU: int
CONNDLG_HIDE_BOX: int
CONNDLG_PERSIST: int
CONNDLG_NOT_PERSIST: int
DISC_UPDATE_PROFILE: int
DISC_NO_FORCE: int
UNIVERSAL_NAME_INFO_LEVEL: int
REMOTE_NAME_INFO_LEVEL: int
WNFMT_MULTILINE: int
WNFMT_ABBREVIATED: int
WNFMT_INENUM: int
WNFMT_CONNECTION: int
NETINFO_DLL16: int
NETINFO_DISKRED: int
NETINFO_PRINTERRED: int
RP_LOGON: int
RP_INIFILE: int
PP_DISPLAYERRORS: int
WNCON_FORNETCARD: int
WNCON_NOTROUTED: int
WNCON_SLOWLINK: int
WNCON_DYNAMIC: int
NetSetupUnknown: int
NetSetupMachine: int
NetSetupWorkgroup: int
NetSetupDomain: int
NetSetupNonExistentDomain: int
NetSetupDnsMachine: int
NetSetupUnknownStatus: int
NetSetupUnjoined: int
NetSetupWorkgroupName: int
NetSetupDomainName: int
NetValidateAuthentication: int
NetValidatePasswordChange: int
NetValidatePasswordReset: int
ACCESS_ACCESS_LIST_INFOLEVEL: int
ACCESS_ACCESS_LIST_PARMNUM: int
SV_ALIST_MTIME_PARMNUM: int
SV_GLIST_MTIME_PARMNUM: int
SV_TYPE_LOCAL_LIST_ONLY: int
SV_ULIST_MTIME_PARMNUM: int



import _win32typing

def OleCreate(
    clsid,
    clsid1,
    obCLSID: _win32typing.PyIID,
    obIID: _win32typing.PyIID,
    renderopt,
    obFormatEtc,
    obOleClientSite: _win32typing.PyIOleClientSite,
    obStorage: _win32typing.PyIStorage,
    /,
) -> _win32typing.PyIOleObject: ...
def OleLoadPicture(
    stream: _win32typing.PyIStream, size, runMode, arg: _win32typing.PyIID, arg1: _win32typing.PyIID, /
) -> _win32typing.PyIUnknown: ...
def OleLoadPicturePath(
    url_or_path: str, unk, reserved, clr, arg: _win32typing.PyIID, arg1: _win32typing.PyIID, /
) -> _win32typing.PyIUnknown: ...
def OleSetContainedObject(unk: _win32typing.PyIUnknown, fContained, /) -> None: ...
def OleTranslateAccelerator(frame: _win32typing.PyIOleInPlaceFrame, frame_info, msg: _win32typing.PyMSG, /) -> None: ...

EMBDHLP_CREATENOW: int
EMBDHLP_DELAYCREATE: int
EMBDHLP_INPROC_HANDLER: int
EMBDHLP_INPROC_SERVER: int
OLECLOSE_NOSAVE: int
OLECLOSE_PROMPTSAVE: int
OLECLOSE_SAVEIFDIRTY: int
OLECMDF_ENABLED: int
OLECMDF_LATCHED: int
OLECMDF_NINCHED: int
OLECMDF_SUPPORTED: int
OLECMDTEXTF_NAME: int
OLECMDTEXTF_NONE: int
OLECMDTEXTF_STATUS: int
OLECREATE_LEAVERUNNING: int
OLEIVERB_DISCARDUNDOSTATE: int
OLEIVERB_HIDE: int
OLEIVERB_INPLACEACTIVATE: int
OLEIVERB_OPEN: int
OLEIVERB_PRIMARY: int
OLEIVERB_SHOW: int
OLEIVERB_UIACTIVATE: int
IID_IObjectWithSite: _win32typing.PyIID
IID_IOleClientSite: _win32typing.PyIID
IID_IOleCommandTarget: _win32typing.PyIID
IID_IOleControl: _win32typing.PyIID
IID_IOleControlSite: _win32typing.PyIID
IID_IOleInPlaceActiveObject: _win32typing.PyIID
IID_IOleInPlaceFrame: _win32typing.PyIID
IID_IOleInPlaceObject: _win32typing.PyIID
IID_IOleInPlaceSite: _win32typing.PyIID
IID_IOleInPlaceSiteEx: _win32typing.PyIID
IID_IOleInPlaceSiteWindowless: _win32typing.PyIID
IID_IOleInPlaceUIWindow: _win32typing.PyIID
IID_IOleLink: _win32typing.PyIID
IID_IOleObject: _win32typing.PyIID
IID_ISpecifyPropertyPages: _win32typing.PyIID
IID_IViewObject: _win32typing.PyIID
IID_IViewObject2: _win32typing.PyIID
